@@ -1,7 +1,18 @@
-# Copyright 2016 Splunk, Inc.
-# SPDX-FileCopyrightText: 2020 2020
 #
-# SPDX-License-Identifier: Apache-2.0
+# Copyright 2021 Splunk Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
 
 """
 The Splunk Software Development Kit for Solutions.
@@ -9,14 +20,11 @@ The Splunk Software Development Kit for Solutions.
 
 from . import (
     acl,
-    compression,
     conf_manager,
     credentials,
     file_monitor,
     hec_config,
-    ip_math,
     log,
-    metadata,
     net_utils,
     orphan_process_monitor,
     pattern,
@@ -31,14 +39,11 @@ from . import (
 
 __all__ = [
     "acl",
-    "compression",
     "conf_manager",
     "credentials",
     "file_monitor",
     "hec_config",
-    "ip_math",
     "log",
-    "metadata",
     "net_utils",
     "orphan_process_monitor",
     "pattern",
@@ -51,4 +56,4 @@ __all__ = [
     "utils",
 ]
 
-__version__ = "4.2.0"
+__version__ = "4.3.1"
